
data { 
	int<lower=1> Nchoice; // Total choices
	int<lower=1> Nvisit; // Number of choice situations
	int<lower=1> Nprov; // Number of alternatives (first is outside option)
	int<lower=1> Nindiv; // Number of individuals
	
	int<lower=1,upper=Nvisit> visit[Nchoice]; // Visit ID of choice
	int<lower=1,upper=Nprov> prov[Nchoice]; // Provider ID of choice
	int<lower=1,upper=Nindiv> indiv[Nvisit]; // Provider ID of visit

	vector[Nchoice] price; // X variable with random coefficient
	int<lower=1> Nx; // Number of variables without random coefficients
	matrix[Nchoice,Nx] x; // X variables without random coefficients

	int<lower=1,upper=Nprov> Nchoiceset[Nvisit]; // Number of alternatives in each choice set
	int<lower=1,upper=Nprov> y[Nvisit]; // Choice
}

parameters {
	vector[Nprov-1] xi_free;
	real<lower=-5,upper=5> alpha_mu;
	real<lower=0.000001> alpha_s;
	vector<lower=-5,upper=5>[Nx] beta;
}

transformed parameters {

	// Normalize outside option
	vector[Nprov] xi;
	xi[1] <- 0;
	for (i in 2:Nprov)
		xi[i] <- xi_free[i-1];
}

model {
  	int pos;
  	pos <- 1;
  	
  	// Random Coefficient
  	alpha ~ normal(alpha_mu,alpha_s);
	//for (i in 1:Nindiv)
	//	alpha[i] ~ normal(alpha_mu,alpha_s);

	// Log likelihood
	for (n in 1:Nvisit) {
		y[n] ~ categorical_logit(
			xi[segment(prov,pos,Nchoiceset[n])] + 
			segment(price,pos,Nchoiceset[n]) * alpha[indiv[n]] +
			block(x,pos,1,Nchoiceset[n],Nx) * beta);
		pos <- pos + Nchoiceset[n];
	}
	
}
